@@ -1,10 +1,6 @@
 # argparse for parsing of incoming arguments
-import argparse
-
-# argparse to parse arguments
-from DataPlotter.Models import DataSet
 from DataPlotter.Models import DataPlotter
-
+import argparse
 
 # parse input with the help of an argument parser
 parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter)
@@ -17,15 +13,13 @@ args = parser.parse_args()
 # get the file path from arguments
 filePath = args.file
 
-# create the dataplotter
-plotter = DataPlotter(filePath)
+# create a DataPlotter
+plotter = DataPlotter("exampleData.dat")
 
-# plot the data
-plotter.plot()
+# filter our data
+def filterFunction(data):
+    return data + [abs(data[2]-data[1])]
 
-# calculate the difference of first columns
-#   start with 1, bc 0 is x value
-plotter.filterData(lambda l: l+ [l[2]-l[1]])
+plotter.filterData(filterFunction)
 
-# plot the data
 plotter.plot()
\ No newline at end of file
